import type { ConnectUIEvent } from './types';
import type { MaybePromise } from '@nangohq/types';
export type OnConnectEvent = (event: ConnectUIEvent) => MaybePromise<void>;
export interface ConnectUIProps {
    /**
     * The unique token to identify your user. It is required to make UI work but can be set asynchronously.
     */
    sessionToken?: string | undefined;
    /**
     * The base URL to load the UI
     * @default `https://connect.nango.dev`
     */
    baseURL?: string;
    /**
     * The base URL to reach Nango API
     * @default `https://api.nango.dev`
     */
    apiURL?: string;
    /**
     * A callback to listen to events sent by Nango Connect
     */
    onEvent?: OnConnectEvent;
    /**
     * Control OAuth popup close detection.
     * If set to false a closed popup will not be detected as a failed authorization
     * @default true
     */
    detectClosedAuthWindow?: boolean;
}
export declare class ConnectUI {
    iframe: HTMLIFrameElement | null;
    private isReady;
    private listener;
    private sessionToken;
    private baseURL;
    private apiURL;
    private onEvent;
    private detectClosedAuthWindow?;
    constructor({ sessionToken, baseURL, apiURL, detectClosedAuthWindow, onEvent }: ConnectUIProps);
    /**
     * Open UI in an iframe and listen to events
     */
    open(): void;
    /**
     * Set the session token and send it to the Connect UI iframe
     */
    setSessionToken(sessionToken: string): void;
    /**
     * Close UI and clear state
     */
    close(): void;
    private sendSessionToken;
}
//# sourceMappingURL=connectUI.d.ts.map